@@ -27,21 +27,22 @@
 
 (defun llm-request--content ()
   "From the current buffer, return the content of the response."
-  (buffer-substring-no-properties
-   (or (and (boundp 'url-http-end-of-headers) url-http-end-of-headers)
-      (save-match-data
-        (save-excursion
-          (goto-char (point-min))
-          (search-forward "\n\n" nil t)
-          (forward-line)
-          (point))))
-    (point-max)))
+  (decode-coding-string
+   (buffer-substring-no-properties
+    (or (and (boundp 'url-http-end-of-headers) url-http-end-of-headers)
+        (save-match-data
+          (save-excursion
+            (goto-char (point-min))
+            (search-forward "\n\n" nil t)
+            (forward-line)
+            (point))))
+    (point-max)) 'utf-8))
 
 (defvar-local llm-request--partial-callback nil
   "The callback to call when a partial response is received.")
 
-(cl-defun llm-request-sync (url &key headers data timeout)
-  "Make a request to URL.  The parsed response will be returned.
+(cl-defun llm-request-sync-raw-output (url &key headers data timeout)
+  "Make a request to URL.  The raw text response will be returned.
 
 HEADERS will be added in the Authorization header, in addition to
 standard json header. This is optional.
@@ -53,13 +54,27 @@ TIMEOUT is the number of seconds to wait for a response."
   (let ((url-request-method "POST")
         (url-request-extra-headers
          (append headers '(("Content-Type" . "application/json"))))
-        (url-request-data (json-encode data)))
+        (url-request-data (encode-coding-string (json-encode data) 'utf-8)))
     (let ((buf (url-retrieve-synchronously url t nil (or timeout 5))))
       (if buf
-          (with-current-buffer buf
-            (json-read-from-string (llm-request--content)))
+          (with-current-buffer buf (llm-request--content))
         (error "LLM request timed out")))))
 
+(cl-defun llm-request-sync (url &key headers data timeout)
+  "Make a request to URL.  The parsed response will be returned.
+
+HEADERS will be added in the Authorization header, in addition to
+standard json header. This is optional.
+
+DATA will be jsonified and sent as the request body.
+This is required.
+
+TIMEOUT is the number of seconds to wait for a response."
+  (json-read-from-string (llm-request-sync-raw-output url
+                                                      :headers headers
+                                                      :data data
+                                                      :timeout timeout)))
+
 (defun llm-request--handle-new-content (&rest _)
   "Handle new content in the current buffer."
   (save-match-data
@@ -99,7 +114,7 @@ the buffer is turned into JSON and passed to ON-SUCCESS."
         (url-mime-encoding-string "identity")
         (url-request-extra-headers
          (append headers '(("Content-Type" . "application/json"))))
-        (url-request-data (json-encode data)))
+        (url-request-data (encode-coding-string (json-encode data) 'utf-8)))
     (let ((buffer
            (url-retrieve
             url
